#
# spec file for package assertj-core
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# The automatic requires would be java-headless >= 9, but the
# binaries are java 8 compatible
%define __requires_exclude java-headless
Name:           assertj-core
Version:        3.25.3
Release:        150200.5.6.1
Summary:        Library of assertions similar to fest-assert
License:        Apache-2.0
URL:            https://joel-costigliola.github.io/assertj/
Source0:        https://github.com/joel-costigliola/assertj-core/archive/assertj-build-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  java-devel >= 9
BuildRequires:  maven-local
BuildRequires:  mvn(biz.aQute.bnd:bnd-maven-plugin)
BuildRequires:  mvn(junit:junit)
BuildRequires:  mvn(net.bytebuddy:byte-buddy)
BuildRequires:  mvn(org.apiguardian:apiguardian-api)
BuildRequires:  mvn(org.hamcrest:hamcrest)
BuildRequires:  mvn(org.junit.jupiter:junit-jupiter-api)
BuildRequires:  mvn(org.opentest4j:opentest4j)
Requires:       java-headless >= 1.8
#!BuildRequires: junit5-minimal
BuildArch:      noarch

%description
A set of strongly-typed assertions to use for unit testing
(either with JUnit or TestNG).

%package javadoc
Summary:        API documentation for %{name}

%description javadoc
This package provides API documentation for %{name}.

%prep
%setup -q -n assertj-assertj-build-%{version}

%pom_remove_plugin -r :maven-javadoc-plugin
%pom_remove_plugin -r :maven-enforcer-plugin
%pom_remove_plugin -r :jacoco-maven-plugin
%pom_remove_plugin -r :spotless-maven-plugin
#pom_remove_plugin -r :bnd-maven-plugin
%pom_remove_plugin -r :bnd-resolver-maven-plugin
%pom_remove_plugin -r :bnd-testing-maven-plugin
%pom_remove_plugin -r :nexus-staging-maven-plugin
%pom_remove_plugin -r :license-maven-plugin
%pom_remove_plugin -r :flatten-maven-plugin
%pom_remove_dep -r :mockito-bom
%pom_remove_dep -r :junit-bom

%pom_disable_module assertj-core-kotlin assertj-tests/assertj-integration-tests
%pom_disable_module assertj-core-groovy assertj-tests/assertj-integration-tests

%pom_add_dep org.apiguardian:apiguardian-api:1.1.2:provided

%build
%{mvn_build} -f -- -Dproject.build.sourceEncoding=UTF-8 -Dmaven.compiler.release=8 -Dsource=8

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%doc README.md CONTRIBUTING.md
%license LICENSE.txt

%files javadoc -f .mfiles-javadoc
%doc CONTRIBUTING.md
%license LICENSE.txt

%changelog
* Fri May 24 2024 fstrba@suse.com
- Require in OBS junit5-minimal to avoid provider choice
* Tue Apr 30 2024 fstrba@suse.com
- Upgrade to version 3.25.3
  * Deprecations:
    + Deprecate the following date/time related assertions in favor
    of isCloseTo:
  - isEqualToIgnoringHours
  - isEqualToIgnoringMinutes
  - isEqualToIgnoringSeconds
  - isEqualToIgnoringMillis
  - isEqualToIgnoringNanos
  - isInSameHourAs
  - isInSameMinuteAs
  - isInSameSecondAs
    + Deprecate asList in favor of asInstanceOf
  * New Features:
    + Add Descriptable#describedAs(Supplier<String>)
    + Add isInThePast and isInTheFuture to LocalDate assertions
    + Add isInThePast and isInTheFuture to the missing Java 8
    date/time types
    + Add isRecord and isNotRecord to Class assertions
    + Add hasNullValue and doesNotHaveNullValue to
    AtomicReferenceAssert
    + Add asBoolean|Byte|Short|Int|Long|Float|Double to String
    assertions
    + Add hasRecordComponents to Class assertions
    + Add getters for field path in ComparisonDifference
    + Allow to compare enum and string fields in the recursive
    comparison
    + Provide value when assertThatThrownBy / thenThrownBy fail
    + Add isSealed and isNotSealed to Class assertions
    + Add assertThatCharSequence to disambiguate Groovy's GString
    + Change the way the properties are collected using the
    Class.getMethods() API instead of iterating the class
    hierarchy using Class.declaredMethods()
    + Add default constructor for RecursiveComparator
    + Add isPrimitive and isNotPrimitive to Class assertions
    + Add anyOf(ThrowingConsumer...) and allOf(ThrowingConsumer...)
    + Show the array/iterable under test in the assertion error
    message when it is not empty but should have been
  * Bug Fixes:
    + Compare Java types from javax and com.sun by their equals
    method in recursive comparison
    + The recursive comparison comparingOnlyFields did not treat
    array/iterable elements as root objects
    + Fixes a bug when failing assertions on DirectoryStream types
    + Fix handling of null containers in the recursive assertion
    + Handle null values in map entry sets when formatting
    + Fix NPE when expected and actual field values are null
    + Fix NPE on anyMatch when actual contains null and
    Objects::isNull is used as predicate
    + Fix misleading subsequence failure messages in string
    assertions
    + Do not ignore nested fields of types specified in
    comparingOnlyFieldsOfTypes
    + containsExactly does not work properly with maps not using
    equals to compare keys
    + Escape percentage in shouldContainExactly error message
    + Fix recursive comparison of ignored types in unordered
    collection
    + Revert "Provide value when assertThatThrownBy/thenThrownBy
    fail"
    + Revert "fix: containsExactly does not work properly with maps
    not using equals to compare keys"
    + Fix unresolvable Javadoc stylesheet URLs, simplify
    configuration
    + Fix missing configuration for MatcherAssert soft assertions
    + Make deprecation notice visible in AbstractAssert#asList
    + Recursive comparison uses equals on root object when
    useOverriddenEquals is enabled
    + satisfiesExactlyInAnyOrder fails if actual overrides equals
    + Avoid calling actual.hashCode() and expected.hashCode() in
    DualValue
    + Recursive comparison checks for existence of fields in types
    that parameterize nested unordered iterables
    + Lock maven-clean-plugin version for all modules
    + Fix a performance regression in the recursive comparison
    related to FieldLocation
    + Don't fail when the recursive comparison checks compared
    fields in collection elements
  * Improvements
    + Add Spotless
    + Use Bnd feature to write resolved bndrun files to output
    folder
    + Add Throwable stack trace to ShouldHaveClause
    + Avoid copy of any Collection instance in
    Iterables::assertContains
    + Add Throwable stack trace to ShouldHaveRootCauseInstance and
    ShouldHaveRootCauseExactlyInstance
    + Add missing description to nested condition
    + Make nestable condition factory accept conditions on super
    types
    + Add varargs overload to Assert::hasString and
    Assert::doesNotHaveString
    + Improve recursive comparison performance by caching field and
    field names result
    + Document performance cost of ignoring collection order
    + Track visited values and their comparison differences so that
    they can be reused
    + Use hash code for compareUnorderedIterables to improve
    performance in some common cases
    + Improve recursive comparison error message regarding equals
    methods used for JDK types
    + Format large arrays as strings
    + Remove null check as isArray already performs it
    + Fix PrimitiveArralList/TransformlingList test file names
    + Add exception for usages of isEqualTo and isNotEqualTo on
    assertions
    + Add check for missing fields in recursive comparison where
    specific fields are requested for comparison
    + Improve efficiency of iterable string conversion
    + Add more tests for usingRecursiveComparison
    + Checks that compared fields exist before running the recursive
    comparison
    + Remove maven-surefire-plugin duplicate version
    + Remove Maven default goal
    + Add dependency graph workflow
    + Normalize non-breaking spaces like regular white spaces
    + AbstractOffsetDateTimeAssert::isBetween parameter names should
    use inclusive, not exclusive
    + Invoke isNotNull in returns and doesNotReturn
    + Cache node names in ComparingFields, ComparingProperties
    + Cache node names in ComparingNormalizedFields
    + Use simpler syntax in
    DefaultRecursiveComparisonIntrospectionStrategy
    .getChildrenNodeNamesOf
    + Update to Contributor Covenant Code of Conduct v2.1
    + Correct contains assertion Javadoc to reflect method behavior
    in case actual is not empty and the group of values to look
    for is
    + Fix Javadoc typos
    + Improving null-safety of isEqualToNormalizingNewlines
    + Speed up for BinaryDiff performance
    + Upgrade workflows to Java 21
    + Apply flatten-maven-plugin to assertj-core and assertj-guava
* Wed May  1 2019 jengelh@inai.de
- Ensure neutrality of descriptions.
* Tue Apr 30 2019 fstrba@suse.com
- Initial packaging of assertj-core 3.8.0
